@@ -328,8 +328,8 @@ var searchData=
   ['tdsdbopen_325',['tdsdbopen',['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
   ['tdsdump_5fclose_326',['tdsdump_close',['../a00431.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
   ['tdsdump_5fcol_327',['tdsdump_col',['../a00431.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
-  ['tdsdump_5fdump_5fbuf_328',['tdsdump_dump_buf',['../a00431.html#a79449d2f35a8acc8ed0585044f75524d',1,'log.c']]],
-  ['tdsdump_5flog_329',['tdsdump_log',['../a00431.html#ab45c291105027e69836002e1dd586141',1,'log.c']]],
+  ['tdsdump_5fdump_5fbuf_5fimpl_328',['tdsdump_dump_buf_impl',['../a00431.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
+  ['tdsdump_5flog_5fimpl_329',['tdsdump_log_impl',['../a00431.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
   ['tdsdump_5foff_330',['tdsdump_off',['../a00431.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
   ['tdsdump_5foff_5fitem_331',['tdsdump_off_item',['../a01329.html',1,'']]],
   ['tdsdump_5fon_332',['tdsdump_on',['../a00431.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
