@@ -1537,10 +1537,9 @@ int tdsdump_wopen(const wchar_t *filename);
 #endif
 #include <freetds/pushvis.h>
 void tdsdump_close(void);
-void tdsdump_dump_buf(const char* file, unsigned int level_line, const char *msg, const void *buf, size_t length);
+void tdsdump_dump_buf_impl(const char* file, unsigned int level_line, const char *msg, const void *buf, size_t length);
 void tdsdump_col(const TDSCOLUMN *col);
-#undef tdsdump_log
-void tdsdump_log(const char* file, unsigned int level_line, const char *fmt, ...)
+void tdsdump_log_impl(const char* file, unsigned int level_line, const char *fmt, ...)
 #if defined(__GNUC__) && __GNUC__ >= 2
 #if defined(__MINGW32__)
 	__attribute__ ((__format__ (ms_printf, 3, 4)))
@@ -1549,10 +1548,8 @@ void tdsdump_log(const char* file, unsigned int level_line, const char *fmt, ...
 #endif
 #endif
 ;
-#define TDSDUMP_LOG_FAST if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log
-#define tdsdump_log TDSDUMP_LOG_FAST
-#define TDSDUMP_BUF_FAST if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf
-#define tdsdump_dump_buf TDSDUMP_BUF_FAST
+#define tdsdump_log if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log_impl
+#define tdsdump_dump_buf if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf_impl
 
 extern bool tds_write_dump;
 extern int tds_debug_flags;
